TTransportErrorType class
Error codes for TTransportException.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ALREADY_OPEN → const int
- END_OF_FILE → const int
- NEGATIVE_SIZE → const int
- NOT_OPEN → const int
- TIMED_OUT → const int
- UNKNOWN → const int